pub struct PyRedisMessageBusBacking { /* private fields */ }Trait Implementations
Sourceimpl Debug for PyRedisMessageBusBacking
impl Debug for PyRedisMessageBusBacking
impl DerefToPyAny for PyRedisMessageBusBacking
impl ExtractPyClassWithClone for PyRedisMessageBusBacking
Sourceimpl<'py> IntoPyObject<'py> for PyRedisMessageBusBacking
impl<'py> IntoPyObject<'py> for PyRedisMessageBusBacking
Sourcetype Target = PyRedisMessageBusBacking
type Target = PyRedisMessageBusBacking
The Python output type
Sourcetype Output = Bound<'py, <PyRedisMessageBusBacking as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyRedisMessageBusBacking as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyRedisMessageBusBacking
impl PyClass for PyRedisMessageBusBacking
Sourceimpl PyClassImpl for PyRedisMessageBusBacking
impl PyClassImpl for PyRedisMessageBusBacking
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PyRedisMessageBusBacking as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyRedisMessageBusBacking>
type Layout = <<PyRedisMessageBusBacking as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyRedisMessageBusBacking>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForPyRedisMessageBusBacking
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
fn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyClassNewTextSignature for PyRedisMessageBusBacking
impl PyClassNewTextSignature for PyRedisMessageBusBacking
const TEXT_SIGNATURE: &'static str = "(trader_id, instance_id, config_json)"
Sourceimpl PyStubType for PyRedisMessageBusBacking
impl PyStubType for PyRedisMessageBusBacking
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
fn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for PyRedisMessageBusBacking
impl PyTypeInfo for PyRedisMessageBusBacking
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Auto Trait Implementations
impl Freeze for PyRedisMessageBusBacking
impl RefUnwindSafe for PyRedisMessageBusBacking
impl Send for PyRedisMessageBusBacking
impl Sync for PyRedisMessageBusBacking
impl Unpin for PyRedisMessageBusBacking
impl UnsafeUnpin for PyRedisMessageBusBacking
impl UnwindSafe for PyRedisMessageBusBacking